@@ -1,25 +1,15 @@
 package uk.ac.starlink.topcat;
 
 import gnu.jel.CompilationException;
-import java.awt.Color;
-import java.awt.Component;
-import java.awt.Toolkit;
-import java.awt.event.ActionListener;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
-import java.util.logging.Logger;
 import javax.swing.AbstractListModel;
-import javax.swing.ComboBoxEditor;
 import javax.swing.ComboBoxModel;
-import javax.swing.JComboBox;
-import javax.swing.JOptionPane;
-import javax.swing.UIManager;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.TableColumnModelEvent;
 import javax.swing.event.TableColumnModelListener;
-import javax.swing.plaf.basic.BasicComboBoxEditor;
 import javax.swing.table.TableColumnModel;
 import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ColumnInfo;
@@ -42,16 +32,15 @@ import uk.ac.starlink.util.gui.WeakTableColumnModelListener;
  * and this should be ignored (treated as null) for the purposes
  * of data access.
  * 
- * <p>The {@link #createComboBox} method provides a JComboBox which is a
+ * <p>The {@link ColumnDataComboBox} class should generally be used as a
  * suitable host for instances of this class.
  *
  * @author   Mark Taylor
  * @since    23 Jan 2005
  */
-@SuppressWarnings({"unchecked","rawtypes"})
 public class ColumnDataComboBoxModel
-        extends AbstractListModel
-        implements TableColumnModelListener, ComboBoxModel {
+        extends AbstractListModel<ColumnData>
+        implements TableColumnModelListener, ComboBoxModel<ColumnData> {
 
     private final TopcatModel tcModel_;
     private final Filter filter_;
@@ -62,8 +51,6 @@ public class ColumnDataComboBoxModel
     private List<ColumnData> modelColumns_;
     private Object selected_;
 
-    private static final Logger logger =
-        Logger.getLogger( "uk.ac.starlink.topcat" );
     private static final ValueInfo INDEX_INFO =
         new DefaultValueInfo( "index", Long.class, "Row index" );
 
@@ -146,7 +133,7 @@ public class ColumnDataComboBoxModel
         this( tcModel, dataClazz, hasNone, false );
     }
 
-    public Object getElementAt( int index ) {
+    public ColumnData getElementAt( int index ) {
         return activeColumns_.get( index );
     }
 
@@ -438,34 +425,6 @@ public class ColumnDataComboBoxModel
 
     public void columnSelectionChanged( ListSelectionEvent evt ) {}
 
-    /**
-     * Constructs and returns a JComboBox suitable for use with
-     * a <code>ColumnDataComboBoxModel</code>.  It installs 
-     * (and deinstalls as appropriate)
-     * {@link javax.swing.ComboBoxEditor}s which allow for 
-     * textual expressions to be interpreted as JEL expressions based
-     * on the TopcatModel on which this model is based.
-     * This facility is only available/useful in the case that the 
-     * combo box is editable; so the returned combo box is editable.
-     * Currently no default renderer is required or installed.
-     *
-     * @return   new custom combo box
-     */
-    public static JComboBox createComboBox() {
-        JComboBox comboBox = new JComboBox() {
-            public void setModel( ComboBoxModel model ) {
-                super.setModel( model );
-                if ( model instanceof ColumnDataComboBoxModel ) {
-                    ColumnDataComboBoxModel emodel =
-                        (ColumnDataComboBoxModel) model;
-                    setEditor( new ColumnDataEditor( emodel, this ) );
-                }
-            }
-        };
-        comboBox.setEditable( true );
-        return comboBox;
-    }
-
     /**
      * Creates a ColumnData object simply representing a single column
      * of a table.
@@ -522,120 +481,6 @@ public class ColumnDataComboBoxModel
         boolean acceptColumn( ValueInfo info );
     }
 
-    /**
-     * ComboBoxEditor implementation suitable for use with a 
-     * ColumnDataComboBoxModel.
-     */
-    private static class ColumnDataEditor extends BasicComboBoxEditor {
-
-        private final ColumnDataComboBoxModel model_;
-        private final Component parent_;
-        private final ComboBoxEditor base_;
-        private final Color okColor_;
-        private final Color errColor_;
-        private String text_;
-        private ColumnData data_;
-
-        /**
-         * Constructor.
-         *
-         * @param  model   model which this editor can work with
-         */
-        public ColumnDataEditor( ColumnDataComboBoxModel model,
-                                 Component parent ) {
-            model_ = model;
-            parent_ = parent;
-            base_ = new JComboBox().getEditor();
-            okColor_ = UIManager.getColor( "ComboBox.foreground" );
-            errColor_ = UIManager.getColor( "ComboBox.disabledForeground" );
-        }
-
-        public void setItem( Object obj ) {
-            base_.setItem( toStringOrData( obj ) );
-        }
-
-        public Object getItem() {
-            return toStringOrData( base_.getItem() );
-        }
-
-        /**
-         * Configures the editor component to give a visual indication
-         * of whether a legal column data object is currently visible.
-         *
-         * @param  isOK  true for usable data, false for not
-         */
-        private void setOk( boolean isOk ) {
-            base_.getEditorComponent()
-                 .setForeground( isOk ? okColor_ : errColor_ );
-        }
-
-        /**
-         * Takes an object which is a possible content of this editor and
-         * returns a corresponding ColumnData object if possible,
-         * otherwise a string.
-         * This method informs the user via a popup if a string cannot
-         * be converted to data.  It caches values so that it does not
-         * keep showing the same popup for the same string.
-         *
-         * @param  item   input object
-         * @return   output object, should be of type String or
-         *           (preferably) ColumnData
-         */
-        private Object toStringOrData( Object item ) {
-            if ( item instanceof ColumnData ) {
-                text_ = null;
-                data_ = (ColumnData) item;
-            }
-            else if ( item instanceof String ) {
-                String txt = (String) item;
-                if ( ! txt.equals( text_ ) ) {
-                    ColumnData colData;
-                    CompilationException err;
-                    try {
-                        colData = model_.stringToColumnData( txt );
-                        err = null;
-                    }
-                    catch ( CompilationException e ) {
-                        colData = null;
-                        err = e;
-                    }
-                    text_ = txt;
-                    data_ = colData;
-                    if ( err != null ) {
-                        setOk( false );
-                        JOptionPane
-                       .showMessageDialog( parent_, err.getMessage(),
-                                           "Evaluation Error",
-                                           JOptionPane.ERROR_MESSAGE );
-                    }
-                }
-            }
-            else if ( item == null ) {
-                data_ = null;
-                text_ = null;
-            }
-            setOk( data_ != null || text_ == null
-                                 || text_.trim().length() == 0 );
-            return data_ != null ? data_ : text_;
-        }
-
-        public Component getEditorComponent() {
-            return base_.getEditorComponent();
-        }
-
-        public void selectAll() {
-            base_.selectAll();
-        }
-
-        public void removeActionListener( ActionListener listener ) {
-            base_.removeActionListener( listener );
-        }
-
-        public void addActionListener( ActionListener listener ) {
-            base_.addActionListener( listener );
-        }
-    }
-
     /**
      * ColumnData implementation for a column defined by a JEL expression.
      * This just extends SyntheticColumn so that it can provide sensible
