@@ -253,6 +253,7 @@ public class ResourceIcon implements Icon {
         WARNING = makeIcon( "warning_triangle.png" ),
         APPROVE_ALL = makeIcon( "approve_all.png" ),
         MEASURE = makeIcon( "measure.png" ),
+        LOCK = makeIcon( "lock2.png" ),
 
         /* Plot2 icons. */
         UP_DOWN = makeIcon( "updown8.png" ),
@@ -261,6 +262,7 @@ public class ResourceIcon implements Icon {
         PLOT_PAIR = makeIcon( "pairplot.png" ),
         PLOT_QUAD = makeIcon( "quadplot.png" ),
         PLOT_HISTO = makeIcon( "histoplot.png" ),
+        PLOT_AREA = makeIcon( "areaplot.png" ),
         PLOT2_PLANE = makeIcon( "plot2plane.png" ),
         PLOT2_SKY = makeIcon( "plot2sky.png" ),
         PLOT2_CUBE = makeIcon( "plot2cube.png" ),
@@ -721,6 +723,7 @@ public class ResourceIcon implements Icon {
         putMap( nameMap, "ADD_PLOT_DATA", toAddIcon( PLOT_DATA ) );
         putMap( nameMap, "ADD_PLOT_PAIR", toAddIcon( PLOT_PAIR ) );
         putMap( nameMap, "ADD_PLOT_QUAD", toAddIcon( PLOT_QUAD ) );
+        putMap( nameMap, "ADD_PLOT_AREA", toAddIcon( PLOT_AREA ) );
         putMap( nameMap, "ADD_PLOT_HISTO", toAddIcon( PLOT_HISTO ) );
         putMap( nameMap, "ADD_FORM_MARK", toAddIcon( TTRI.FORM_MARK ) );
         putMap( nameMap, "ADD_FORM_SIZE", toAddIcon( TTRI.FORM_SIZE ) );
@@ -738,6 +741,8 @@ public class ResourceIcon implements Icon {
                          toAddIcon( TTRI.FORM_LINEARFIT ) );
         putMap( nameMap, "ADD_FORM_QUANTILE", toAddIcon( TTRI.FORM_QUANTILE ) );
         putMap( nameMap, "ADD_PLOT_LABEL", toAddIcon( TTRI.PLOT_LABEL ) );
+        putMap( nameMap, "ADD_PLOT_AREALABEL",
+                         toAddIcon( TTRI.PLOT_AREALABEL ) );
         putMap( nameMap, "ADD_PLOT_CONTOUR", toAddIcon( TTRI.PLOT_CONTOUR ) );
         putMap( nameMap, "ADD_FORM_GRID", toAddIcon( TTRI.FORM_GRID ) );
         putMap( nameMap, "ADD_FORM_SKYDENSITY",
