@@ -13,6 +13,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
 import java.util.HashMap;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
@@ -121,13 +122,26 @@ public class TopcatUtils {
         /* Get the apparent table. */
         StarTable table =
             new MetaCopyStarTable( tcModel.getApparentStarTable() );
+        int ncol = table.getColumnCount();
+
+        /* Remove metadata that's only intended for internal topcat use. */
+        for ( int icol = 0; icol < ncol; icol++ ) {
+            ColumnInfo cinfo = table.getColumnInfo( icol );
+            List<DescribedValue> auxData = cinfo.getAuxData();
+            for ( Iterator<DescribedValue> it = auxData.iterator();
+                  it.hasNext(); ) {
+                DescribedValue dval = it.next();
+                if ( TopcatUtils.COLID_INFO.equals( dval.getInfo() ) ) {
+                    it.remove();
+                }
+            }
+        }
 
         /* Identify synthetic columns, and adjust their column descriptions
          * to include the expression that defines them.
          * Before a table save (though not session save) operation is
          * an appropriate time to do this, since the expression calculation
          * behaviour will be lost following this serialization. */
-        int ncol = table.getColumnCount();
         for ( int icol = 0; icol < ncol; icol++ ) {
             ColumnInfo cinfo = table.getColumnInfo( icol );
             String expr =
@@ -632,13 +646,12 @@ public class TopcatUtils {
      * @param  msgLines  lines of text to appear in dialogue window
      * @param  title   dialogue window title
      */
-    @SuppressWarnings("rawtypes")
     public static void addSubset( JComponent parent, TopcatModel tcModel,
                                   BitSet matchMask, String dfltName,
                                   String[] msgLines, String title ) {
         int nmatch = matchMask.cardinality();
         Box nameLine = Box.createHorizontalBox();
-        JComboBox nameSelector = tcModel.createNewSubsetNameSelector();
+        JComboBox<String> nameSelector = tcModel.createNewSubsetNameSelector();
         nameSelector.setSelectedItem( dfltName );
         nameLine.add( new JLabel( "Subset name: " ) );
         nameLine.add( nameSelector );
@@ -695,13 +708,12 @@ public class TopcatUtils {
      * Returns the subset name corresponding to the currently
      * selected value of a row subset selector box.
      *
-     * @param rsetSelector  combo box returned by
+     * @param rsetNameSelector  combo box returned by
      *        TopcatModel.createNewSubsetNameSelector
      * @return   subset name as string, or null
      */
-    @SuppressWarnings("rawtypes")
-    private static String getSubsetName( JComboBox rsetSelector ) {
-        Object item = rsetSelector.getSelectedItem();
+    private static String getSubsetName( JComboBox<String> rsetNameSelector ) {
+        Object item = rsetNameSelector.getSelectedItem();
         if ( item == null ) {
             return null;
         }
@@ -709,9 +721,6 @@ public class TopcatUtils {
             String name = (String) item;
             return name.trim().length() > 0 ? name : null;
         }
-        else if ( item instanceof RowSubset ) {
-            return ((RowSubset) item).getName();
-        }
         else {
             assert false;
             return item.toString();
