@@ -76,7 +76,6 @@ import uk.ac.starlink.util.gui.ShrinkWrapper;
  * @author   Mark Taylor
  * @since    29 Sep 2009
  */
-@SuppressWarnings({"unchecked","rawtypes"})
 public class DalMultiPanel extends JPanel {
 
     private final DalMultiService service_;
@@ -90,14 +89,15 @@ public class DalMultiPanel extends JPanel {
     private final ColumnSelector raSelector_;
     private final ColumnSelector decSelector_;
     private final ColumnSelector srSelector_;
-    private final JComboBox modeSelector_;
+    private final JComboBox<MulticoneMode> modeSelector_;
     private final SpinnerNumberModel parallelModel_;
-    private final JComboBox erractSelector_;
+    private final JComboBox<ConeErrorPolicy> erractSelector_;
     private final Action startAction_;
     private final Action stopAction_;
     private final JComponent[] components_;
     private final TopcatListener tcListener_;
     private final ToggleButtonModel coverageModel_;
+    private final JComponent urlLine_;
     private Coverage lastCoverage_;
     private URL lastCoverageUrl_;
     private TopcatModel tcModel_;
@@ -133,19 +133,21 @@ public class DalMultiPanel extends JPanel {
         /* Field for service URL. */
         urlField_ = new JTextField();
         JLabel urlLabel = new JLabel( service.getName() + " URL: " );
-        Box urlLine = Box.createHorizontalBox();
+        urlLine_ = Box.createHorizontalBox();
         cList.add( urlField_ );
         cList.add( urlLabel );
-        urlLine.add( urlLabel );
-        urlLine.add( urlField_ );
-        main.add( urlLine );
+        urlLine_.add( urlLabel );
+        urlLine_.add( urlField_ );
+        main.add( urlLine_ );
         main.add( Box.createVerticalStrut( 10 ) );
 
         /* Field for input table. */
-        final JComboBox tableSelector = new TablesListComboBox( 250 );
+        final JComboBox<TopcatModel> tableSelector =
+            new TablesListComboBox( 250 );
         tableSelector.addItemListener( new ItemListener() {
             public void itemStateChanged( ItemEvent evt ) {
-                setInputTable( (TopcatModel) tableSelector.getSelectedItem() );
+                setInputTable( tableSelector
+                              .getItemAt( tableSelector.getSelectedIndex() ) );
             }
         } );
         JLabel tableLabel = new JLabel( "Input Table: " );
@@ -211,7 +213,7 @@ public class DalMultiPanel extends JPanel {
 
         /* Multicone output mode selector. */
         main.add( Box.createVerticalStrut( 10 ) );
-        modeSelector_ = new JComboBox( getMulticoneModes() );
+        modeSelector_ = new JComboBox<MulticoneMode>( getMulticoneModes() );
         Box modeLine = Box.createHorizontalBox();
         JLabel modeLabel = new JLabel( "Output Mode: " );
         modeLine.add( modeLabel );
@@ -243,8 +245,8 @@ public class DalMultiPanel extends JPanel {
                 public void focusGained( FocusEvent evt ) {
                 }
             } );
-            urlLine.add( Box.createHorizontalStrut( 5 ) );
-            urlLine.add( serviceCoverageView_ );
+            urlLine_.add( Box.createHorizontalStrut( 5 ) );
+            urlLine_.add( serviceCoverageView_ );
 
             /* Table coverage icon. */
             queryCoverageView_ = new CoverageView( "table" );
@@ -312,7 +314,8 @@ public class DalMultiPanel extends JPanel {
         JSpinner parallelSpinner = new JSpinner( parallelModel_ );
         cList.add( parallelLabel );
         cList.add( parallelSpinner );
-        erractSelector_ = new JComboBox( getConeErrorPolicies( service ) );
+        erractSelector_ =
+            new JComboBox<ConeErrorPolicy>( getConeErrorPolicies( service ) );
         JLabel erractLabel = new JLabel( ERRACT_LABEL + ": " );
         cList.add( erractLabel );
         cList.add( erractSelector_ );
@@ -358,6 +361,15 @@ public class DalMultiPanel extends JPanel {
         updateServiceCoverage();
     }
 
+    /**
+     * Returns the component in which the URL selector is located.
+     *
+     * @return  URL selector container
+     */
+    public JComponent getServiceUrlBox() {
+        return urlLine_;
+    }
+
     /**
      * Update the service coverage component if the currently selected
      * service URL has changed.
@@ -523,7 +535,8 @@ public class DalMultiPanel extends JPanel {
             Object conv = srSelector_.getModel().getConverterModel()
                                                 .getSelectedItem();
             srSelector_.setTable( tcModel );
-            ComboBoxModel srColModel = srSelector_.getModel().getColumnModel();
+            ComboBoxModel<ColumnData> srColModel =
+                srSelector_.getModel().getColumnModel();
             assert srColModel instanceof ColumnDataComboBoxModel;
             if ( srColModel instanceof ColumnDataComboBoxModel ) {
                 try {
@@ -613,7 +626,7 @@ public class DalMultiPanel extends JPanel {
                  .initCause( e );
         }
         ConeErrorPolicy erract =
-            (ConeErrorPolicy) erractSelector_.getSelectedItem();
+            erractSelector_.getItemAt( erractSelector_.getSelectedIndex() );
         TopcatModel tcModel = tcModel_;
         if ( tcModel == null ) {
             throw new NullPointerException( "No table selected" );
@@ -636,7 +649,8 @@ public class DalMultiPanel extends JPanel {
         }
         Number parNum = parallelModel_.getNumber();
         int parallelism = parNum == null ? 1 : parNum.intValue();
-        MulticoneMode mcMode = (MulticoneMode) modeSelector_.getSelectedItem();
+        MulticoneMode mcMode =
+            modeSelector_.getItemAt( modeSelector_.getSelectedIndex() );
         StarTableFactory tfact = ControlWindow.getInstance().getTableFactory();
 
         /* Assemble objects based on this information. */
