@@ -27,6 +27,7 @@ import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import uk.ac.starlink.table.join.AnisotropicCartesianMatchEngine;
+import uk.ac.starlink.table.join.CdsHealpixSkyPixellator;
 import uk.ac.starlink.table.join.CombinedMatchEngine;
 import uk.ac.starlink.table.join.CuboidCartesianMatchEngine;
 import uk.ac.starlink.table.join.EllipseCartesianMatchEngine;
@@ -37,7 +38,6 @@ import uk.ac.starlink.table.join.EqualsMatchEngine;
 import uk.ac.starlink.table.join.HtmSkyPixellator;
 import uk.ac.starlink.table.join.IsotropicCartesianMatchEngine;
 import uk.ac.starlink.table.join.MatchEngine;
-import uk.ac.starlink.table.join.PixtoolsHealpixSkyPixellator;
 import uk.ac.starlink.table.join.ProgressIndicator;
 import uk.ac.starlink.table.join.RangeModelProgressIndicator;
 import uk.ac.starlink.table.join.ErrorSkyMatchEngine;
@@ -55,11 +55,10 @@ import uk.ac.starlink.ttools.func.CoordsRadians;
  *
  * @author   Mark Taylor (Starlink)
  */
-@SuppressWarnings({"unchecked","rawtypes"})
 public class MatchWindow extends AuxWindow implements ItemListener {
 
     private final int nTable;
-    private final JComboBox engineSelector;
+    private final JComboBox<MatchEngine> engineSelector;
     private final Map<MatchEngine,MatchSpec> matchSpecs;
     private final CardLayout paramCards;
     private final JComponent paramContainer;
@@ -98,7 +97,7 @@ public class MatchWindow extends AuxWindow implements ItemListener {
         }
 
         /* Prepare a combo box which can select the engines. */
-        engineSelector = new JComboBox( engines );
+        engineSelector = new JComboBox<MatchEngine>( engines );
         engineSelector.addItemListener( this );
 
         /* Set up an action to start the match. */
@@ -204,7 +203,7 @@ public class MatchWindow extends AuxWindow implements ItemListener {
      * @return  match engine
      */
     private MatchEngine getMatchEngine() {
-        return (MatchEngine) engineSelector.getSelectedItem();
+        return engineSelector.getItemAt( engineSelector.getSelectedIndex() );
     }
 
     /**
@@ -438,14 +437,14 @@ public class MatchWindow extends AuxWindow implements ItemListener {
         Arrays.fill( someLengths4, someLength );
         MatchEngine skyPlus1Engine = createCombinedEngine( "Sky + X",
             new MatchEngine[] {
-                new FixedSkyMatchEngine( new PixtoolsHealpixSkyPixellator(),
+                new FixedSkyMatchEngine( new CdsHealpixSkyPixellator(),
                                          someAngle ),
                 new AnisotropicCartesianMatchEngine( someLengths1 ),
             }
         );
         MatchEngine skyPlus2Engine = createCombinedEngine( "Sky + XY",
             new MatchEngine[] {
-                new FixedSkyMatchEngine( new PixtoolsHealpixSkyPixellator(),
+                new FixedSkyMatchEngine( new CdsHealpixSkyPixellator(),
                                          someAngle ),
                 new AnisotropicCartesianMatchEngine( someLengths2 ),
             }
@@ -457,11 +456,9 @@ public class MatchWindow extends AuxWindow implements ItemListener {
             }
         };
         return new MatchEngine[] {
-            new FixedSkyMatchEngine( new PixtoolsHealpixSkyPixellator(),
-                                     someAngle ),
-            new ErrorSkyMatchEngine( new PixtoolsHealpixSkyPixellator(),
-                                     someAngle ),
-            new EllipseSkyMatchEngine( new PixtoolsHealpixSkyPixellator(),
+            new FixedSkyMatchEngine( new CdsHealpixSkyPixellator(), someAngle ),
+            new ErrorSkyMatchEngine( new CdsHealpixSkyPixellator(), someAngle ),
+            new EllipseSkyMatchEngine( new CdsHealpixSkyPixellator(),
                                        someAngle ),
             new SphericalPolarMatchEngine( someLength ),
             new EqualsMatchEngine(),
