@@ -19,13 +19,13 @@ import javax.swing.JComponent;
 import javax.swing.JPanel;
 import javax.swing.JPopupMenu;
 import javax.swing.JScrollPane;
+import javax.swing.ListModel;
 import javax.swing.event.ListDataEvent;
 import javax.swing.event.ListDataListener;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
 import uk.ac.starlink.topcat.ResourceIcon;
 import uk.ac.starlink.topcat.TopcatListener;
-import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.topcat.TopcatModel;
 import uk.ac.starlink.ttools.plot2.Plotter;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
@@ -74,7 +74,7 @@ public class MultiFormLayerControl extends FormLayerControl {
      *                        options
      */
     public MultiFormLayerControl( PositionCoordPanel posCoordPanel,
-                                  TypedListModel<TopcatModel> tablesModel,
+                                  ListModel<TopcatModel> tablesModel,
                                   Specifier<ZoneId> zsel, boolean autoPopulate,
                                   NextSupplier nextSupplier,
                                   TopcatListener tcListener, Icon controlIcon,
@@ -185,15 +185,25 @@ public class MultiFormLayerControl extends FormLayerControl {
 
         /* Set up an action for each form-family of plotters, and each
          * standalone plotter. */
-        List<Action> formActionList = new ArrayList<Action>();
+        List<Action> modeFormActList = new ArrayList<>();
         for ( ModePlotter.Form form : modePlotterMap_.keySet() ) {
             ModePlotter<?>[] modePlotters =
                 modePlotterMap_.get( form ).toArray( new ModePlotter<?>[ 0 ] );
-            formActionList.add( new ModeFormAction( modePlotters, form ) );
+            modeFormActList.add( new ModeFormAction( modePlotters, form ) );
         }
+        List<Action> singleFormActList = new ArrayList<>();
         for ( Plotter<?> plotter : singlePlotterList_ ) {
-            formActionList.add( new SingleFormAction( plotter ) );
+            singleFormActList.add( new SingleFormAction( plotter ) );
         }
+        List<Action> formActionList = new ArrayList<>();
+        formActionList.addAll( modeFormActList );
+        formActionList.addAll( singleFormActList );
+
+        /* Somewhat hacky way to fix the default action as the first
+         * plotter in the supplied list. */
+        dfltFormAct_ = plotters[ 0 ] instanceof ModePlotter
+                     ? modeFormActList.get( 0 )
+                     : singleFormActList.get( 0 );
 
         /* Populate a menu with these actions. */
         final JPopupMenu formMenu = new JPopupMenu( "Forms" );
@@ -219,7 +229,6 @@ public class MultiFormLayerControl extends FormLayerControl {
         if ( zsel != null ) {
             addZoneTab( zsel );
         }
-        dfltFormAct_ = formActionList.get( 0 );
     }
 
     protected FormControl[] getFormControls() {
@@ -352,7 +361,8 @@ public class MultiFormLayerControl extends FormLayerControl {
      */
     private ModeFormControl createModeFormControl( ModePlotter<?>[] plotters ) {
         ModeFormControl fc =
-            new ModeFormControl( baseConfigger_, plotters, subsetKeys_ );
+            new ModeFormControl( baseConfigger_, plotters, subsetKeys_,
+                                 getPositionCoordPanel().getCoords() );
         fc.setTable( getTopcatModel(), getSubsetManager(), getSubsetStack() );
         return fc;
     }
