@@ -2,12 +2,16 @@ package uk.ac.starlink.topcat.plot2;
 
 import java.awt.Component;
 import java.awt.Rectangle;
+import javax.swing.ListModel;
 import uk.ac.starlink.topcat.TopcatModel;
-import uk.ac.starlink.topcat.TypedListModel;
+import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.SingleGanger;
 import uk.ac.starlink.ttools.plot2.Surface;
 import uk.ac.starlink.ttools.plot2.PlotType;
+import uk.ac.starlink.ttools.plot2.config.ConfigKey;
+import uk.ac.starlink.ttools.plot2.data.AreaCoord;
+import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.geom.PlanarSurface;
 import uk.ac.starlink.ttools.plot2.geom.PlaneAspect;
 import uk.ac.starlink.ttools.plot2.geom.PlanePlotType;
@@ -39,7 +43,7 @@ public class PlanePlotWindow
      * @param  tablesModel  list of available tables
      */
     public PlanePlotWindow( Component parent,
-                            TypedListModel<TopcatModel> tablesModel ) {
+                            ListModel<TopcatModel> tablesModel ) {
         super( "Plane Plot", parent, PLOT_TYPE, PLOT_GUI, tablesModel );
         getToolBar().addSeparator();
         addHelp( "PlanePlotWindow" );
@@ -59,6 +63,14 @@ public class PlanePlotWindow
                   .createPanel( PLOT_TYPE.getPointDataGeoms()[ 0 ], npos,
                                 XY_SPOTTERS );
         }
+        public PositionCoordPanel createAreaCoordPanel() {
+            return new AreaCoordPanel( AreaCoord.PLANE_COORD, new Coord[ 0 ],
+                                       new ConfigKey<?>[ 0 ] ) {
+                public DataGeom getDataGeom() {
+                    return PLOT_TYPE.getPointDataGeoms()[ 0 ];
+                }
+            };
+        }
         public boolean hasPositions() {
             return true;
         }
